@@ -13,20 +13,20 @@ def test_write():
     assert len(zip_file.namelist()) == 6
 
 
-def test_write_no_grids():
+def test_write_grids():
     file_path = './tests/assets/unnamed.hbjson'
     # Write without grids
-    zip_path = writer(file_path, include_grids=False, include_vectors=True, writer='vtk',
+    zip_path = writer(file_path, include_grids=True, writer='vtk',
                       target_folder='./tests/assets/temp')
     assert os.path.isfile(zip_path)
     zip_file = zipfile.ZipFile(zip_path)
-    assert len(zip_file.namelist()) == 7
+    assert len(zip_file.namelist()) == 8
 
 
-def test_write_no_vectors():
+def test_write_vectors():
     file_path = './tests/assets/unnamed.hbjson'
     # Write without vectors
-    zip_path = writer(file_path, include_grids=True, include_vectors=False, writer='vtk',
+    zip_path = writer(file_path, include_sensors='vectors', writer='vtk',
                       target_folder='./tests/assets/temp')
     assert os.path.isfile(zip_path)
     zip_file = zipfile.ZipFile(zip_path)
@@ -36,8 +36,7 @@ def test_write_no_vectors():
 def test_write_no_grids_no_vectors():
     file_path = './tests/assets/unnamed.hbjson'
     # Write without grids & vectors
-    zip_path = writer(file_path, include_grids=False, include_vectors=False,
-                      writer='vtk', target_folder='./tests/assets/temp')
+    zip_path = writer(file_path, writer='vtk', target_folder='./tests/assets/temp')
     assert os.path.isfile(zip_path)
     zip_file = zipfile.ZipFile(zip_path)
     assert len(zip_file.namelist()) == 6
